/****************************************************************************
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 *~                             IR Kernel                                    ~
 *~                         Copyright(C) 1993                                ~
 *~                       Software Kinetics Ltd.                             ~
 *~                        All Rights Reserved                               ~
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Copyright Software Kinetics Ltd.
 * 
 * Software Kinetics Ltd. has granted a licence of this software to
 * National Library of Canada.
 *
 * The National Library of Canada grants to the user a royalty-free
 * non-exclusive licence in perpetuity to use, modify, improve,
 * reproduce and sell the software.
 *
 * The software is provided to the user "as is" without warranty of
 * any kind.  Neither Software Kinetics Ltd. nor the National Library
 * of Canada warrants,guarantees or makes any representation regarding
 * the use, or the results of the use of the software in terms of
 * accuracy,reliability, or otherwise.  The entire risk as results and
 * performance of the software is assumed by the user. Neither
 * Software Kinetics Ltd. nor the National Library of Canada shall be
 * liable for any direct, indirect, consequential or incidental
 * damages arising out the use of software.
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
 *
 * Program: cspconn.c
 *
 * Purpose: Accept a TCP connection request and returns the new socketFd
 *          through the parameter newsocketFd.
 *
 * Invocation:
 *
 * Input Arguments:
 *
 * Output/Exit Values: None
 *
 * Functions used: cs_Pconnect_request()
 *
 * Version: Date:   93/05/12
 *          Name:   Jim Saunders & Benjamin Yen
 *          Reason: First Draft of IR Target Kernel
 *
 * Reference: IR KERNEL - TARGET PRELIMINARY SOFTWARE DESIGN DOCUMENT
 *            IR KERNEL - TARGET SOFTWARE DETAIL DESIGN DOCUMENT
 *            IR KERNEL - INTERFACE REQUIREMENTS SPECIFICATION
 *            OSI - ANSI Z39.50 DOCUMENTATION
 *
 * Notes:
 *
 * $Log: ir.h,v $
 *
 *****************************************************************************/

#include <stdio.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <sys/errno.h>
#include "ir.h"
#include "irconst.h"
#include "irerror.h"
#include "irassoc.h"

extern int errno;

/*****************************************************************************
 *
 * Function: cs_Pconnect_request
 *
 * Purpose: Accept a TCP connection request and returns the new socketFd
 *          through the parameter newsocketFd.
 *
 * Input Arguments: socketFd - TCP service port file Id
 *                  peer     - TCP control structure
 *
 * Output Return values:  SUCCESS   - connection established
 *                        FAILED    - connection attempt failed
 *
 * Output Arguments: newsocketFd - New TCP service port file Id
 *
 * External Variables:
 *
 * Function used:  accept()
 *
 * Algorithm:
 *
 * Version: Date:   93/05/12
 *          Name:   Jim Saunders & Benjamin Yen
 *          Reason: First Draft of IR Target Kernel
 *
 * Reference: IR KERNEL - TARGET PRELIMINARY SOFTWARE DESIGN DOCUMENT
 *            IR KERNEL - TARGET SOFTWARE DETAIL DESIGN DOCUMENT
 *            IR KERNEL - INTERFACE REQUIREMENTS SPECIFICATION
 *            OSI - ANSI Z39.50 DOCUMENTATION
 *
 * Notes:
 *
 ****************************************************************************/

int
cs_Pconnect_request(socketFd, peer, newsocketFd)
    int socketFd;                /* socketFd for TCP service port   */
    struct sockaddr *peer;
    int *newsocketFd;                /* socketFd for the new connection */
{

    int addrlen;

#ifdef DEBUG_LEVEL1
    fprintf(DEBUG_FILE1, "Calling cs_Pconnect_request ... socketFd=%d\n", socketFd);
#endif

    /* accept the TCP connection request */
    if ((*newsocketFd = accept(socketFd, (struct sockaddr *) peer, &addrlen)) < 0)
    {
        display_error("KERNEL", ERR_ACCEPT_CONNECT, errno);
        return (FAILED);
    }
    else
        return (SUCCESS);

}                                /* end of procedure cs_Pconnect_request */
