/****************************************************************************
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 *~                             IR Kernel                                    ~
 *~                         Copyright(C) 1993                                ~
 *~                       Software Kinetics Ltd.                             ~
 *~                        All Rights Reserved                               ~
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Copyright Software Kinetics Ltd.
 * 
 * Software Kinetics Ltd. has granted a licence of this software to
 * National Library of Canada.
 *
 * The National Library of Canada grants to the user a royalty-free
 * non-exclusive licence in perpetuity to use, modify, improve,
 * reproduce and sell the software.
 *
 * The software is provided to the user "as is" without warranty of
 * any kind.  Neither Software Kinetics Ltd. nor the National Library
 * of Canada warrants,guarantees or makes any representation regarding
 * the use, or the results of the use of the software in terms of
 * accuracy,reliability, or otherwise.  The entire risk as results and
 * performance of the software is assumed by the user. Neither
 * Software Kinetics Ltd. nor the National Library of Canada shall be
 * liable for any direct, indirect, consequential or incidental
 * damages arising out the use of software.
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
 *
 * Program: cssend.c
 *
 * Purpose: This file contains the function to send data via a TCP socketFd.
 *
 * Invocation:
 *
 * Input Arguments:
 *
 * Output/Exit Values: None
 *
 * Functions used: cs_send_data()
 *
 * Version: Date:   93/05/12
 *          Name:   Jim Saunders & Benjamin Yen
 *          Reason: First Draft of IR Target Kernel
 *
 * Reference: IR KERNEL - TARGET PRELIMINARY SOFTWARE DESIGN DOCUMENT
 *            IR KERNEL - TARGET SOFTWARE DETAIL DESIGN DOCUMENT
 *            IR KERNEL - INTERFACE REQUIREMENTS SPECIFICATION
 *            OSI - ANSI Z39.50 DOCUMENTATION
 *
 * Notes:
 *
 * $Log: ir.h,v $
 *
 *****************************************************************************/

#include <stdio.h>
#include "ir.h"
#include "irerror.h"
#include <sys/types.h>
#include <sys/socket.h>
#include "irconst.h"

/*****************************************************************************
 *
 * Function: cs_send_data
 *
 * Purpose: Send data via a TCP socket.
 *
 * Input Arguments:  data_buffer    - data to transmit
 *                   nbytes         - number of bytes to transmit
 *                   socket         - TCP socket to use
 *
 * Return values:    SUCCESS   - data sent
 *                   FAILED    - transmission error
 *
 * Output Arguments:  none
 *
 * Function used:  send
 *
 * Version: Date:   93/05/12
 *          Name:   Jim Saunders & Benjamin Yen
 *          Reason: First Draft of IR Target Kernel
 *
 * References:
 *
 * Notes:
 *
 ****************************************************************************/

int
cs_send_data(data_buffer, nbytes, socket)
    char *data_buffer;                /* pointer to data buffer */
    int nbytes;                        /* bytes to send */
    int socket;                        /* TCP socket to use */
{
    int bytesSent;

#ifdef DEBUG_LEVEL1
    fprintf(DEBUG_FILE1, "Calling cs_send_data ... \n");
#endif

    bytesSent = send(socket, data_buffer, nbytes, 0);

#ifdef DEBUG_LEVEL1
    fprintf(DEBUG_FILE1, "cs_send_data: want to send=%d and %d sent \n", nbytes, bytesSent);
#endif

    if (bytesSent == nbytes)
        return (SUCCESS);
    else
        return (FAILED);

}                                /* end of procedure cs_send_data */
