/****************************************************************************
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 *~                             IR Kernel                                    ~
 *~                         Copyright(C) 1993                                ~
 *~                       Software Kinetics Ltd.                             ~
 *~                        All Rights Reserved                               ~
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Copyright Software Kinetics Ltd.
 * 
 * Software Kinetics Ltd. has granted a licence of this software to
 * National Library of Canada.
 *
 * The National Library of Canada grants to the user a royalty-free
 * non-exclusive licence in perpetuity to use, modify, improve,
 * reproduce and sell the software.
 *
 * The software is provided to the user "as is" without warranty of
 * any kind.  Neither Software Kinetics Ltd. nor the National Library
 * of Canada warrants,guarantees or makes any representation regarding
 * the use, or the results of the use of the software in terms of
 * accuracy,reliability, or otherwise.  The entire risk as results and
 * performance of the software is assumed by the user. Neither
 * Software Kinetics Ltd. nor the National Library of Canada shall be
 * liable for any direct, indirect, consequential or incidental
 * damages arising out the use of software.
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
 *
 * Program: irsndreq.c
 *
 * Purpose: This file contains function to send the request APDU to the client.
 *
 * Invocation:
 *
 * Input Arguments:
 *
 * Output/Exit Values: None
 *
 * Functions used: ira_send_request()
 *
 * Version: Date:   93/05/12
 *          Name:   Benjamin Yen
 *          Reason: First Draft of IR Target Kernel
 *
 * Reference: IR KERNEL - TARGET PRELIMINARY SOFTWARE DESIGN DOCUMENT
 *            IR KERNEL - TARGET SOFTWARE DETAIL DESIGN DOCUMENT
 *            IR KERNEL - INTERFACE REQUIREMENTS SPECIFICATION
 *            OSI - ANSI Z39.50 DOCUMENTATION
 *
 * Notes:
 *
 * $Log: ir.h,v $
 *
 *****************************************************************************/

#include "ir.h"
#include "irconst.h"
#include "asn_incl.h"
#include "irassoc.h"

/*****************************************************************************
 *
 * Function: ira_send_request
 *
 * Purpose: This function sends an APDU request to the Origin.
 *
 * Input Arguments:     assocId    - point to association info
 *
 * Return values:       SUCCESS    - APDU has been sent successfully
 *                      FAILED     - APDU transmission failed
 *
 * Output Arguments:    none
 *
 * Function used:       cs_send_data
 *
 * Version: Date:   93/05/12
 *          Name:   Benjamin Yen
 *          Reason: First Draft of IR Target Kernel
 *
 * References:
 *
 * Notes:
 *
 ****************************************************************************/

int
ira_send_request(assocId)
    struct assoc_struct **assocId;
{
    int result;

#ifdef DEBUG_LEVEL1
    fprintf(DEBUG_FILE1, "Calling ira_send_request ...\n");
#endif

#ifdef DEBUG_LEVEL2
    fprintf(DEBUG_FILE2, "ira_send_request: Begin Dump APDU\n");
    ir_fwrite((*assocId)->APDU_ptr, (*assocId)->APDUsize, 1, DEBUG_FILE2);
    fprintf(DEBUG_FILE2, "ira_send_request: End Dump APDU\n");
#endif

    result = cs_send_data((*assocId)->APDU_ptr, (*assocId)->APDUsize, (*assocId)->socket_no[CLIENTSOCK]);

    return (result);

}                                /* end of procedure ira_send_request */
