/****************************************************************************
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 *~                             IR Kernel                                    ~
 *~                         Copyright(C) 1993                                ~
 *~                       Software Kinetics Ltd.                             ~
 *~                        All Rights Reserved                               ~
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Copyright Software Kinetics Ltd.
 * 
 * Software Kinetics Ltd. has granted a licence of this software to
 * National Library of Canada.
 *
 * The National Library of Canada grants to the user a royalty-free
 * non-exclusive licence in perpetuity to use, modify, improve,
 * reproduce and sell the software.
 *
 * The software is provided to the user "as is" without warranty of
 * any kind.  Neither Software Kinetics Ltd. nor the National Library
 * of Canada warrants,guarantees or makes any representation regarding
 * the use, or the results of the use of the software in terms of
 * accuracy,reliability, or otherwise.  The entire risk as results and
 * performance of the software is assumed by the user. Neither
 * Software Kinetics Ltd. nor the National Library of Canada shall be
 * liable for any direct, indirect, consequential or incidental
 * damages arising out the use of software.
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
 *
 * Program: tpgetpdu.c
 *
 * Purpose: This is the target process black box getting APDU and decoding
 *          program.
 *
 * Invocation:
 *
 * Input Arguments:
 *
 * Output/Exit Values: None
 *
 * Functions used:
 *
 * Version: Date:   93/05/12
 *          Name:   Benjamin Yen
 *          Reason: First Draft of IR Target Kernel
 *
 * Reference: IR KERNEL - TARGET PRELIMINARY SOFTWARE DESIGN DOCUMENT
 *            IR KERNEL - TARGET SOFTWARE DETAIL DESIGN DOCUMENT
 *            IR KERNEL - INTERFACE REQUIREMENTS SPECIFICATION
 *            OSI - ANSI Z39.50 DOCUMENTATION
 *
 * Notes:
 *
 * $Log: ir.h,v $
 *
 *****************************************************************************/

#include <stdio.h>
#include <sys/types.h>
#include <sys/socket.h>
#include "tp.h"
#include "irerror.h"
#include "irassoc.h"
#include "tpconst.h"
#include "asn_incl.h"

/*****************************************************************************
 *
 * Function: tpa_service_event
 *
 * Purpose: To receive an APDU from a TCP data stream and decode it to an
 *          IR PDU.
 *
 * Input Arguments:
 *              socketFd - socket Fd for communicating to IR kernel
 *
 * External Variables:
 *
 * Output Return values: SUCCESS or FAILED
 *
 * Output Arguments:
 *              PDUptr - decoded PDU from the received APDU
 *
 * External Variables:
 *
 * Function used:
 *
 * Algorithm:
 *
 * Version:
 *
 * References:
 *
 * Notes:
 *
 ****************************************************************************/
tpa_service_event(socketFd, PDUptr)
    int socketFd;
    APDU *PDUptr;
{

    int val;
    ENV_TYPE env;
    SBuf buf;
    char *APDU_ptr;
    int nbytesRead;
    AsnLen decodedLen;

#ifdef DEBUG_LEVEL1
    fprintf(DEBUG_FILE1, "BBOX:Calling tpa_service_event\n");
#endif

    /* allocate twice the maximum message size */
    APDU_ptr = (char *) malloc(MAXMESSAGESIZE * 2);

    nbytesRead = recv(socketFd, APDU_ptr, MAXMESSAGESIZE, 0);

#ifdef DEBUG_LEVEL3
    fprintf(DEBUG_FILE3, "BBOX:tpa_service_event: nbytesRead=%d\n", nbytesRead);
#endif

    if (nbytesRead <= 0)
    {
        free(APDU_ptr);
        return (FAILED);
    }

    InitNibbleMem(MAXMESSAGESIZE, MAXMESSAGESIZE);

    SBufInstallData(&buf, APDU_ptr, MAXMESSAGESIZE * 2);
    SBufResetInReadMode(&buf);

#ifdef DEBUG_LEVEL2
    fprintf(DEBUG_FILE2, "BBOX:begin dump received data\n");
    ir_fwrite(SBufDataPtr(&buf), nbytesRead + 25, 1, DEBUG_FILE2);
    fprintf(DEBUG_FILE2, "BBOX:End dump received data\n");
#endif

    decodedLen = 0;
    if ((val = setjmp(env)) == 0)
    {
        BDecAPDU(&buf, PDUptr, &decodedLen, env);

#ifdef DEBUG_LEVEL2
        fprintf(DEBUG_FILE2, "BBOX:tpa_service_event: %ld Bytes Decoded \n", decodedLen);
        fprintf(DEBUG_FILE2, "BBOX:Begin Dump PDU data\n");
        if (PDUptr->choiceId == APDU_INITREQ)
            PrintInitializeReq(DEBUG_FILE2, PDUptr->a.initReq, 0);
        else if (PDUptr->choiceId == APDU_SEARCHREQ)
            PrintSearchReq(DEBUG_FILE2, PDUptr->a.searchReq, 0);
        else if (PDUptr->choiceId == APDU_PRESENTREQ)
            PrintPresentReq(DEBUG_FILE2, PDUptr->a.presentReq, 0);
        fprintf(DEBUG_FILE2, "BBOX:End Dump PDU data\n");
#endif

        free(APDU_ptr);
        return (SUCCESS);
    }
    else
    {
        display_error("KERNEL", ERR_DECODE_APDU, errno);
        free(APDU_ptr);
        return (FAILED);
    }

}                                /* end of procedure cs_Pdata_indication */
